# okland

okland is a python wrapper for handling static code analysis toolings. most promiment feature is it's ability to extract prometheus metrics from results and send them to a pushgateway.

![Okland with KICS](docs/okland_kics_long.png)


## supported toolings

- kics.io